@@ -91,8 +91,14 @@ sub validateData {
     if (not ref $entry){
         die mkerror(4095,trm("sorry, don't know the field you are talking about"));
     }
-    return undef if not $entry->{set}{required} and (not defined $formData->{$fieldName} or length($formData->{$fieldName}) == 0);
-    return ($entry->{validator} ? $entry->{validator}->($formData->{$fieldName},$fieldName,$formData) : undef);
+    return if not $entry->{set}{required} and (not defined $formData->{$fieldName} or length($formData->{$fieldName}) == 0);
+    if ($entry->{validator}){
+        my $start = time;
+        my $data = $entry->{validator}->($formData->{$fieldName},$fieldName,$formData);
+        $self->log->debug(sprintf("validator %s: %0.2fs",$fieldName,time-$start));
+        return $data;
+    }
+    return;
 }
 
 =head2 processData($args)
@@ -165,7 +171,7 @@ sub getFieldValue {
         if (ref $entry->{getter} eq 'CODE'){
             my $start = time;
             my $data = $entry->{getter}->($self);
-            $self->log->debug(sprintf("ran getter %s: %0.2fs",$field,time-$start));
+            $self->log->debug(sprintf("getter %s: %0.2fs",$field,time-$start));
             return $data;
         }
         else {
